#include "scanner.ih"

void Scanner::newDefinition()
{
    push(StartCondition_::line);
}

